@@ -839,11 +839,18 @@ class recset(Generic[T]):
             rowsTemp = []
             
             # __rowsをフィルタする
+            foundRow = False
             for index, item in self.__dfrows.iterrows():
                 for row in self.__rows:
                     for key in self.__getPrimaryKeys():
                         if getattr(row, key) == item[key]:
-                            rowsTemp.append(row)
+                            foundRow = True
+                            continue
+                        else:
+                            foundRow = False
+                    if foundRow:
+                        rowsTemp.append(row)
+                        break
             self.__rows = rowsTemp
 
             # __dfrowsを再構築する
